@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,6 @@ package com.openexchange.audit.logging;
 import java.util.logging.Filter;
 import java.util.logging.Level;
 import java.util.logging.LogRecord;
-
 import com.openexchange.audit.impl.AuditEventHandler;
 
 /**
@@ -60,14 +59,12 @@ import com.openexchange.audit.impl.AuditEventHandler;
  */
 public class AuditFilter implements Filter {
 
-	public boolean isLoggable(LogRecord record) {
-		if (record.getLoggerName().equals(AuditEventHandler.class.getName())
-				&& record.getLevel() != Level.WARNING
-				&& record.getLevel() != Level.SEVERE) {
-			return false;
-		}
-		
-		return true;
-	}
+    public boolean isLoggable(final LogRecord record) {
+        if (record.getLoggerName().equals(AuditEventHandler.class.getName()) && record.getLevel() != Level.WARNING && record.getLevel() != Level.SEVERE) {
+            return false;
+        }
+
+        return true;
+    }
 
 }
