@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,16 +50,13 @@
 package com.openexchange.audit.osgi;
 
 import static com.openexchange.audit.services.AuditServiceRegistry.getServiceRegistry;
-
 import java.util.Dictionary;
 import java.util.Hashtable;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
-
 import com.openexchange.audit.impl.AuditEventHandler;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.server.osgiservice.DeferredActivator;
@@ -69,83 +66,82 @@ import com.openexchange.server.osgiservice.ServiceRegistry;
  * @author Benjamin Otterbach
  */
 public class AuditActivator extends DeferredActivator {
-	
-	private static transient final Log LOG = LogFactory.getLog(AuditActivator.class);
 
-	private static final Class<?>[] NEEDED_SERVICES = { ConfigurationService.class } ;
-	
-	final Dictionary<Object,Object> serviceProperties;
-	
-	private ServiceRegistration auditServiceRegistration;
+    private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AuditActivator.class));
 
-	public AuditActivator() {
-		super();
-		serviceProperties = new Hashtable<Object,Object>();
-		serviceProperties.put(EventConstants.EVENT_TOPIC, new String[]{
-				"com/openexchange/groupware/*"});
-	}
-	
-	@Override
-	protected Class<?>[] getNeededServices() {
-		return NEEDED_SERVICES;
-	}
+    private ServiceRegistration auditServiceRegistration;
 
-	@Override
-	protected void handleAvailability(Class<?> clazz) {
-		if (LOG.isWarnEnabled()) {
-			LOG.warn("Absent service: " + clazz.getName());
-		}
-		getServiceRegistry().addService(clazz, getService(clazz));
-	}
+    /**
+     * Initializes a new {@link AuditActivator}.
+     */
+    public AuditActivator() {
+        super();
+    }
 
-	@Override
-	protected void handleUnavailability(Class<?> clazz) {
-		if (LOG.isInfoEnabled()) {
-			LOG.info("Re-available service: " + clazz.getName());
-		}
-		getServiceRegistry().removeService(clazz);
-	}
+    @Override
+    protected Class<?>[] getNeededServices() {
+        return new Class<?>[] { ConfigurationService.class };
+    }
 
-	@Override
-	protected void startBundle() throws Exception {
-		try {
+    @Override
+    protected void handleAvailability(final Class<?> clazz) {
+        if (LOG.isWarnEnabled()) {
+            LOG.warn("Absent service: " + clazz.getName());
+        }
+        getServiceRegistry().addService(clazz, getService(clazz));
+    }
+
+    @Override
+    protected void handleUnavailability(final Class<?> clazz) {
+        if (LOG.isInfoEnabled()) {
+            LOG.info("Re-available service: " + clazz.getName());
+        }
+        getServiceRegistry().removeService(clazz);
+    }
+
+    @Override
+    protected void startBundle() throws Exception {
+        try {
             /*
              * (Re-)Initialize service registry with available services
              */
-			{
-				final ServiceRegistry registry = getServiceRegistry();
-				registry.clearRegistry();
-				final Class<?>[] classes = getNeededServices();
-				for (int i = 0; i < classes.length; i++) {
-					final Object service = getService(classes[i]);
-					if (null != service) {
-						registry.addService(classes[i], service);
-					}
-				}
-			}
-			auditServiceRegistration = context.registerService(EventHandler.class.getName(), AuditEventHandler.getInstance(), serviceProperties);
-		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
-			throw t instanceof Exception ? (Exception) t : new Exception(t);
-		}
-		
-	}
+            {
+                final ServiceRegistry registry = getServiceRegistry();
+                registry.clearRegistry();
+                final Class<?>[] classes = getNeededServices();
+                for (final Class<?> classe : classes) {
+                    final Object service = getService(classe);
+                    if (null != service) {
+                        registry.addService(classe, service);
+                    }
+                }
+            }
+            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>();
+            serviceProperties.put(EventConstants.EVENT_TOPIC, new String[] { "com/openexchange/groupware/*" });
+            auditServiceRegistration =
+                context.registerService(EventHandler.class.getName(), AuditEventHandler.getInstance(), serviceProperties);
+        } catch (final Throwable t) {
+            LOG.error(t.getMessage(), t);
+            throw t instanceof Exception ? (Exception) t : new Exception(t);
+        }
 
-	@Override
-	protected void stopBundle() throws Exception {		
-		try {
+    }
+
+    @Override
+    protected void stopBundle() throws Exception {
+        try {
             if (null != auditServiceRegistration) {
-            	auditServiceRegistration.unregister();
-            	auditServiceRegistration = null;
+                auditServiceRegistration.unregister();
+                auditServiceRegistration = null;
             }
             /*
              * Clear service registry
              */
-			getServiceRegistry().clearRegistry();
-		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
-			throw t instanceof Exception ? (Exception) t : new Exception(t);
-		}
-	}
+            getServiceRegistry().clearRegistry();
+        } catch (final Throwable t) {
+            LOG.error(t.getMessage(), t);
+            throw t instanceof Exception ? (Exception) t : new Exception(t);
+        }
+    }
 
 }
